==> simplepycons-1!13.13.0-py3-none-any.whl: simplepycons/_authelia.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (c) 2024 Carsten Igel.
#
# This file is part of simplepycons
# (see https://github.com/carstencodes/simplepycons).
#
# This file is published using the MIT license.
# Refer to LICENSE for more information
#
""""""
# pylint: disable=C0302
# Justification: Code is generated

from typing import TYPE_CHECKING

from .base_icon import Icon

if TYPE_CHECKING:
    from collections.abc import Iterable


class AutheliaIcon(Icon):
    """"""
    @property
    def name(self) -> "str":
        return "authelia"

    @property
    def original_file_name(self) -> "str":
        return "authelia.svg"

    @property
    def title(self) -> "str":
        return "Authelia"

    @property
    def primary_color(self) -> "str":
        return "#113155"

    @property
    def raw_svg(self) -> "str":
        return ''' <svg xmlns="http://www.w3.org/2000/svg"
 role="img" viewBox="0 0 24 24">
    <title>Authelia</title>
     <path d="M10.624.191c-.324.023-.655.011-.97.073-2.883.568-5.244
 2.01-7.074 4.3C1.42 6.014.624 7.652.243 9.48c-.25 1.2-.294 2.402-.191
 3.627.237 2.832 1.377 5.233 3.345 7.26.332.341.775.348
 1.1.055.39-.35.442-.735.124-1.149-.271-.353-.588-.671-.85-1.03-1.625-2.208-2.343-4.674-2.04-7.411.305-2.773
 1.6-5.022 3.723-6.795 1.517-1.267 3.288-1.983
 5.248-2.24.272-.037.552-.083.803-.186.32-.132.478-.564.4-.923-.085-.384-.355-.483-.702-.477-.194.004-.387
 0-.58 0v-.02zm4.639
 3.41c-.312-.008-.582.197-.722.512-.176.4-.027.854.367
 1.096.123.075.256.134.385.199 1.485.737 2.619 1.834 3.319
 3.342.257.554.423 1.15.636
 1.726.162.441.509.656.92.579.425-.08.67-.392.668-.952-.016-.081-.035-.261-.082-.435-.535-1.97-1.579-3.616-3.21-4.847-.598-.453-1.28-.812-1.958-1.14a.782.782
 0 0 0-.323-.08zm-6.939.23a.903.903 0 0
 0-.492.144c-.648.388-1.325.764-1.88 1.266-2.323 2.098-3.262
 4.755-2.905 7.84.55 4.74 4.6 8.021 8.9 7.904l.868-.001a.99.99 0 0 0
 .109-.007c2.491-.312 4.58-1.387 6.146-3.36.488-.615.86-1.336
 1.2-2.049.248-.523-.032-.982-.56-1.12-.38-.1-.72.112-.974.509-.473.737-.89
 1.54-1.491 2.16-1.479 1.52-3.322 2.28-5.466
 2.199-2.405-.091-4.337-1.127-5.758-3.056-1.088-1.475-1.49-3.168-1.32-4.984.184-1.987
 1.038-3.644 2.57-4.927.423-.354.908-.633
 1.365-.946.458-.314.568-.715.314-1.15-.153-.262-.371-.413-.626-.422zm3.417
 2.167C8.724 6.056 6.02 8.625 6 12 5.98 15.29 8.712 18.017 12
 18.02c3.339.005 6.078-2.618 6.062-6.025C18.048 8.45 15.192 5.911
 12.034 6a5.726 5.726 0 0 0-.293-.002zm10.752 1.164a.91.91 0 0
 0-.137.002c-.404.033-.642.295-.74.646-.053.187-.01.432.064.62a9.546
 9.546 0 0 1 .648 3.753 9.994 9.994 0 0 1-1.32 4.76c-1.617 2.84-4.04
 4.53-7.243
 5.12-.343.063-.694.095-1.033.174-.434.103-.688.473-.641.882.044.38.34.646.769.684.132.012.265.002.398.002l-.001-.003c.145
 0 .29.005.434-.002.084-.004.167-.028.25-.04 1.847-.282 3.518-.99
 5.037-2.068 1.708-1.213 3.001-2.78 3.897-4.665 1.1-2.317
 1.375-4.752.906-7.264-.13-.694-.354-1.376-.584-2.046-.125-.362-.389-.537-.704-.555zm-10.449.862c.13
 0 .261.016.392.05.708.18 1.16.787 1.158 1.553.027.504-.211.888-.588
 1.183-.207.163-.236.32-.176.558.264 1.052.52 2.107.763
 3.164.13.568-.019.872-.522
 1.174-.675.404-1.666.354-2.29-.13-.315-.244-.427-.573-.331-.966.252-1.031.494-2.064.762-3.09.086-.33.041-.554-.225-.794-.581-.523-.682-1.253-.317-1.903a1.57
 1.57 0 0 1 1.374-.8z" />
</svg>'''

    @property
    def guidelines_url(self) -> "str | None":
        _value: "str" = ''''''
        if len(_value) > 0:
            return _value
        return None

    @property
    def source(self) -> "str":
        return '''https://github.com/authelia/authelia/blob/831
6cd4eb7a6f0778c8f480c61ad76a88416fc3a/docs/static/images/branding/logo'''

    @property
    def license(self) -> "tuple[str | None, str | None]":
        _type: "str | None" = ''''''
        _url: "str | None" = ''''''

        if _type is not None and len(_type) == 0:
            _type = None

        if _url is not None and len(_url) == 0:
            _url = None

        return _type, _url

    @property
    def aliases(self) -> "Iterable[str]":
        yield from []

==> simplepycons-1!15.2.0-py3-none-any.whl: simplepycons/_authelia.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (c) 2025 Carsten Igel.
#
# This file is part of simplepycons
# (see https://github.com/carstencodes/simplepycons).
#
# This file is published using the MIT license.
# Refer to LICENSE for more information
#
""""""
# pylint: disable=C0302
# Justification: Code is generated

from typing import TYPE_CHECKING

from .base_icon import Icon

if TYPE_CHECKING:
    from collections.abc import Iterable


class AutheliaIcon(Icon):
    """"""
    @property
    def name(self) -> "str":
        return "authelia"

    @property
    def original_file_name(self) -> "str":
        return "authelia.svg"

    @property
    def title(self) -> "str":
        return "Authelia"

    @property
    def primary_color(self) -> "str":
        return "#113155"

    @property
    def raw_svg(self) -> "str":
        return ''' <svg xmlns="http://www.w3.org/2000/svg"
 role="img" viewBox="0 0 24 24">
    <title>Authelia</title>
     <path d="M10.624.191c-.324.023-.655.011-.97.073-2.883.568-5.244
 2.01-7.074 4.3C1.42 6.014.624 7.652.243 9.48c-.25 1.2-.294 2.402-.191
 3.627.237 2.832 1.377 5.233 3.345 7.26.332.341.775.348
 1.1.055.39-.35.442-.735.124-1.149-.271-.353-.588-.671-.85-1.03-1.625-2.208-2.343-4.674-2.04-7.411.305-2.773
 1.6-5.022 3.723-6.795 1.517-1.267 3.288-1.983
 5.248-2.24.272-.037.552-.083.803-.186.32-.132.478-.564.4-.923-.085-.384-.355-.483-.702-.477-.194.004-.387
 0-.58 0v-.02zm4.639
 3.41c-.312-.008-.582.197-.722.512-.176.4-.027.854.367
 1.096.123.075.256.134.385.199 1.485.737 2.619 1.834 3.319
 3.342.257.554.423 1.15.636
 1.726.162.441.509.656.92.579.425-.08.67-.392.668-.952-.016-.081-.035-.261-.082-.435-.535-1.97-1.579-3.616-3.21-4.847-.598-.453-1.28-.812-1.958-1.14a.782.782
 0 0 0-.323-.08zm-6.939.23a.903.903 0 0
 0-.492.144c-.648.388-1.325.764-1.88 1.266-2.323 2.098-3.262
 4.755-2.905 7.84.55 4.74 4.6 8.021 8.9 7.904l.868-.001a.99.99 0 0 0
 .109-.007c2.491-.312 4.58-1.387 6.146-3.36.488-.615.86-1.336
 1.2-2.049.248-.523-.032-.982-.56-1.12-.38-.1-.72.112-.974.509-.473.737-.89
 1.54-1.491 2.16-1.479 1.52-3.322 2.28-5.466
 2.199-2.405-.091-4.337-1.127-5.758-3.056-1.088-1.475-1.49-3.168-1.32-4.984.184-1.987
 1.038-3.644 2.57-4.927.423-.354.908-.633
 1.365-.946.458-.314.568-.715.314-1.15-.153-.262-.371-.413-.626-.422zm3.417
 2.167C8.724 6.056 6.02 8.625 6 12 5.98 15.29 8.712 18.017 12
 18.02c3.339.005 6.078-2.618 6.062-6.025C18.048 8.45 15.192 5.911
 12.034 6a5.726 5.726 0 0 0-.293-.002zm10.752 1.164a.91.91 0 0
 0-.137.002c-.404.033-.642.295-.74.646-.053.187-.01.432.064.62a9.546
 9.546 0 0 1 .648 3.753 9.994 9.994 0 0 1-1.32 4.76c-1.617 2.84-4.04
 4.53-7.243
 5.12-.343.063-.694.095-1.033.174-.434.103-.688.473-.641.882.044.38.34.646.769.684.132.012.265.002.398.002l-.001-.003c.145
 0 .29.005.434-.002.084-.004.167-.028.25-.04 1.847-.282 3.518-.99
 5.037-2.068 1.708-1.213 3.001-2.78 3.897-4.665 1.1-2.317
 1.375-4.752.906-7.264-.13-.694-.354-1.376-.584-2.046-.125-.362-.389-.537-.704-.555zm-10.449.862c.13
 0 .261.016.392.05.708.18 1.16.787 1.158 1.553.027.504-.211.888-.588
 1.183-.207.163-.236.32-.176.558.264 1.052.52 2.107.763
 3.164.13.568-.019.872-.522
 1.174-.675.404-1.666.354-2.29-.13-.315-.244-.427-.573-.331-.966.252-1.031.494-2.064.762-3.09.086-.33.041-.554-.225-.794-.581-.523-.682-1.253-.317-1.903a1.57
 1.57 0 0 1 1.374-.8z" />
</svg>'''

    @property
    def guidelines_url(self) -> "str | None":
        _value: "str" = '''https://www.authelia.com/reference/guides/bra'''
        if len(_value) > 0:
            return _value
        return None

    @property
    def source(self) -> "str":
        return '''https://github.com/authelia/authelia/blob/831
6cd4eb7a6f0778c8f480c61ad76a88416fc3a/docs/static/images/branding/logo'''

    @property
    def license(self) -> "tuple[str | None, str | None]":
        _type: "str | None" = ''''''
        _url: "str | None" = ''''''

        if _type is not None and len(_type) == 0:
            _type = None

        if _url is not None and len(_url) == 0:
            _url = None

        return _type, _url

    @property
    def aliases(self) -> "Iterable[str]":
        yield from []
